Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(643)

Unified Diff: src/interpreter/bytecode-array-builder.h

Issue 2663963003: [Ignition] Rename New and NewWithSpread bytecodes. (Closed)
Patch Set: Update comments Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/debug/debug-evaluate.cc ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/interpreter/bytecode-array-builder.h
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h
index 7bb601b752c0c2a16da56876295baf894d60a46b..378ab739e558a09923d4fac2617032f983fb04a2 100644
--- a/src/interpreter/bytecode-array-builder.h
+++ b/src/interpreter/bytecode-array-builder.h
@@ -218,15 +218,16 @@ class V8_EXPORT_PRIVATE BytecodeArrayBuilder final
// onwards. The final argument must be a spread.
BytecodeArrayBuilder& CallWithSpread(Register callable, RegisterList args);
// Call the new operator. The accumulator holds the |new_target|.
// The |constructor| is in a register and arguments are in |args|.
- BytecodeArrayBuilder& New(Register constructor, RegisterList args,
- int feedback_slot);
+ BytecodeArrayBuilder& Construct(Register constructor, RegisterList args,
+ int feedback_slot);
- // Call the new operator for use with a spread. The accumulator holds the
- // |new_target|. The |constructor| is in a register and arguments are in
+ // Call the Construct operator for use with a spread. The accumulator holds
+ // the |new_target|. The |constructor| is in a register and arguments are in
// |args|. The final argument must be a spread.
- BytecodeArrayBuilder& NewWithSpread(Register constructor, RegisterList args);
+ BytecodeArrayBuilder& ConstructWithSpread(Register constructor,
+ RegisterList args);
// Call the runtime function with |function_id| and arguments |args|.
BytecodeArrayBuilder& CallRuntime(Runtime::FunctionId function_id,
« no previous file with comments | « src/debug/debug-evaluate.cc ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
@@ -218,15 +218,16 @@ class V8_EXPORT_PRIVATE BytecodeArrayBuilder final
// onwards. The final argument must be a spread.
BytecodeArrayBuilder& CallWithSpread(Register callable, RegisterList args);
- // Call the new operator. The accumulator holds the |new_target|.
+ // Call the Construct operator. The accumulator holds the |new_target|.
// The |constructor| is in a register and arguments are in |args|.

Powered by Google App Engine
This is Rietveld 408576698